CryptoGspl class

Inheritance

Constructors

CryptoGspl({required Uint8List data, required GsplDataType dataType, List<CryptoTxElement>? inputs, CryptoTxElement? change})

Properties

change ↔ CryptoTxElement?
getter/setter pair
data Uint8List
getter/setter pair
dataType GsplDataType
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputs List<CryptoTxElement>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getRegistryType() RegistryType
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCBOR() Uint8List
inherited
toCborValue() → CborValue
override
toString() String
A string representation of this object.
inherited
toUR() UR
inherited
toUREncoder(int? maxFragmentLength, int? firstSeqNum, int? minFragmentLength) → dynamic
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCBOR(Uint8List cborPayload) CryptoGspl
fromDataItem(dynamic jsonData) CryptoGspl