GsWalletTronSDK class

Constructors

GsWalletTronSDK()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateSignRequest({String? uuid, required String signData, required String path, int? fee, required String xfp, String? origin}) UR
parseSignature(UR ur) Map<String, dynamic>