RegistryItem class abstract

Implementers

Constructors

RegistryItem()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getRegistryType() RegistryType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCBOR() Uint8List
toCborValue() → CborValue?
toString() String
A string representation of this object.
inherited
toUR() UR
toUREncoder(int? maxFragmentLength, int? firstSeqNum, int? minFragmentLength) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited