RegistryType class

Implementers

Constructors

RegistryType(String _type, int? _tag)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag → dynamic
no setter
type → dynamic
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

BYTES RegistryType
getter/setter pair
CRYPTO_ACCOUNT RegistryType
getter/setter pair
CRYPTO_ADDRESS RegistryType
getter/setter pair
CRYPTO_COIN_INFO RegistryType
getter/setter pair
CRYPTO_ECKEY RegistryType
getter/setter pair
CRYPTO_HDKEY RegistryType
getter/setter pair
CRYPTO_KEYPATH RegistryType
getter/setter pair
CRYPTO_OUTPUT RegistryType
getter/setter pair
CRYPTO_PSBT RegistryType
getter/setter pair
UUID RegistryType
getter/setter pair