SolSignRequest class

Inheritance

Constructors

SolSignRequest({Uint8List? uuid, required Uint8List signData, required SignType signType, required CryptoKeypath derivationPath, String? outputAddress, String? contractAddress, String? origin, int? fee})

Properties

contractAddress String?
final
derivationPath → CryptoKeypath
final
fee int?
final
hashCode int
The hash code for this object.
no setterinherited
origin String?
final
outputAddress String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signData Uint8List
final
signType SignType
final
uuid Uint8List?
getter/setter pair

Methods

getContractAddress() String?
getDerivationPath() String?
getFee() int?
getOrigin() String?
getOutputAddress() String?
getRegistryType() RegistryType
override
getRequestId() Uint8List
getSignData() Uint8List
getSignType() SignType
getSourceFingerprint() Uint8List?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCBOR() Uint8List
inherited
toCborValue() → CborValue
override
toString() String
A string representation of this object.
inherited
toUR() UR
inherited
toUREncoder(int? maxFragmentLength, int? firstSeqNum, int? minFragmentLength) → dynamic
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCBOR(Uint8List cborPayload) SolSignRequest
fromDataItem(dynamic jsonData) SolSignRequest