SolSignature class

Inheritance

Constructors

SolSignature({required Uint8List signature, required Uint8List uuid, String? origin})

Properties

hashCode int
The hash code for this object.
no setterinherited
origin String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature Uint8List
finalinherited
uuid Uint8List
finalinherited

Methods

getOrigin() String?
inherited
getRegistryType() RegistryType
getRequestId() Uint8List
inherited
getSignature() Uint8List
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCBOR() Uint8List
inherited
toCborValue() → CborValue
inherited
toString() String
A string representation of this object.
inherited
toUR() UR
inherited
toUREncoder(int? maxFragmentLength, int? firstSeqNum, int? minFragmentLength) → dynamic
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCBOR(Uint8List cborPayload) → GsSignature
fromDataItem(dynamic jsonData) → GsSignature