TronSignRequest class

Inheritance

Constructors

TronSignRequest({Uint8List? uuid, required Uint8List signData, int? fee, required CryptoKeypath derivationPath, String? origin})

Properties

derivationPath → CryptoKeypath
final
fee int?
final
hashCode int
The hash code for this object.
no setterinherited
origin String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signData Uint8List
final
uuid Uint8List?
getter/setter pair

Methods

getDerivationPath() String?
getFee() int?
getOrigin() String?
getRegistryType() RegistryType
override
getRequestId() Uint8List
getSignData() Uint8List
getSourceFingerprint() Uint8List?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCBOR() Uint8List
inherited
toCborValue() → CborValue
override
toString() String
A string representation of this object.
inherited
toUR() UR
inherited
toUREncoder(int? maxFragmentLength, int? firstSeqNum, int? minFragmentLength) → dynamic
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCBOR(Uint8List cborPayload) TronSignRequest
fromDataItem(dynamic jsonData) TronSignRequest