TronSignature class

Inheritance

Constructors

TronSignature({required Uint8List signature, required Uint8List uuid, String? origin})

Properties

hashCode int
The hash code for this object.
no setterinherited
origin String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature Uint8List
final
uuid Uint8List
getter/setter pair

Methods

getOrigin() String?
getRegistryType() RegistryType
override
getRequestId() Uint8List
getSignature() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCBOR() Uint8List
inherited
toCborValue() → CborValue
override
toString() String
A string representation of this object.
inherited
toUR() UR
inherited
toUREncoder(int? maxFragmentLength, int? firstSeqNum, int? minFragmentLength) → dynamic
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCBOR(Uint8List cborPayload) TronSignature
fromDataItem(dynamic jsonData) TronSignature