UR class

Constructors

UR(Uint8List _cborPayload, [String _type = 'bytes'])
UR.from(dynamic value, {Function? encoding})
factory

Properties

cbor Uint8List
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
no setter

Methods

arraysEqual(List a, List b) bool
decodeCBOR() String
equals(UR ur2) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited