URDecoder class

Constructors

URDecoder({FountainDecoder? fountainDecoder, String type = 'bytes'})

Properties

error Error?
getter/setter pair
expectedType String
getter/setter pair
fountainDecoder → FountainDecoder
final
hashCode int
The hash code for this object.
no setterinherited
result UR?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

estimatedPercentComplete() double
expectedPartCount() int
expectedPartIndexes() List<int>
getProgress() double
isComplete() bool
isError() bool
isSuccess() bool
lastPartIndexes() List<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receivedPartIndexes() List<int>
receivePart(String s) bool
resultError() String
resultUR() UR
toString() String
A string representation of this object.
inherited
validatePart(String type) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(String message) UR
decodeBody(String type, String message) UR
parse(String message) List
parseSequenceComponent(String s) List<int>