UREncoder class

Constructors

UREncoder(UR ur, {int? maxFragmentLength, int? firstSeqNum, int? minFragmentLength})

Properties

cbor Uint8List
no setter
fountainEncoder → FountainEncoder
final
fragments List<Uint8List>
no setter
fragmentsLength int
no setter
hashCode int
The hash code for this object.
no setterinherited
messageLength int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ur UR
final

Methods

encodeWhole() List<String>
nextPart() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

encodePart(String type, FountainEncoderPart part) String
encodeSinglePart(UR ur) String
encodeUR(List<String> pathComponents) String
encodeUri(String scheme, List<String> pathComponents) String