AlphSignRequest class
- Inheritance
-
- Object
- RegistryItem
- AlphSignRequest
Constructors
-
AlphSignRequest({Uint8List? uuid, required Uint8List data, CryptoKeypath? derivationPath, List<
CryptoTxEntity> ? outputs, String? origin})
Properties
- data → Uint8List
-
final
- derivationPath → CryptoKeypath?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- origin → String?
-
final
-
outputs
→ List<
CryptoTxEntity> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid ↔ Uint8List?
-
getter/setter pair
Methods
-
getData(
) → Uint8List -
getOrigin(
) → String? -
getOutputs(
) → List< CryptoTxEntity> ? -
getPath(
) → CryptoKeypath? -
getRegistryType(
) → RegistryType -
override
-
getRequestId(
) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCBOR(
) → Uint8List -
inherited
-
toCborValue(
) → CborValue -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
toUR(
) → UR -
inherited
-
toUREncoder(
int? maxFragmentLength, int? firstSeqNum, int? minFragmentLength) → dynamic -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCBOR(
Uint8List cborPayload) → AlphSignRequest -
fromDataItem(
dynamic jsonData) → AlphSignRequest