GsWalletPsbtSDK class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateInscribeRequest(
{String? uuid, required String commitData, required String revealData, String? origin}) → UR -
generateSignRequest(
{String? uuid, required String psbt, required String path, required String xfp, String? origin}) → UR -
parseInscribeSignature(
UR ur) → Map< String, dynamic> -
parseSignature(
UR ur) → Map< String, dynamic>